Index: ui/gfx/compositor/layer_delegate.h |
diff --git a/ui/gfx/compositor/layer_delegate.h b/ui/gfx/compositor/layer_delegate.h |
index 973d12f97448545494eb0b95409c1aeb3ab6b04b..474689e5be61997add1d0b578ac78355eb5e9010 100644 |
--- a/ui/gfx/compositor/layer_delegate.h |
+++ b/ui/gfx/compositor/layer_delegate.h |
@@ -14,7 +14,7 @@ class Canvas; |
namespace ui { |
-class Animation; |
+class LayerAnimationSequence; |
// A delegate interface implemented by an object that renders to a Layer. |
class COMPOSITOR_EXPORT LayerDelegate { |
@@ -23,8 +23,8 @@ class COMPOSITOR_EXPORT LayerDelegate { |
// clipped to the Layer's invalid rect. |
virtual void OnPaintLayer(gfx::Canvas* canvas) = 0; |
- // Called when |animation| ends. |
- virtual void OnLayerAnimationEnded(const ui::Animation* animation) = 0; |
+ // Called when |seq| ends. |
+ virtual void OnLayerAnimationEnded(const LayerAnimationSequence* seq) = 0; |
protected: |
virtual ~LayerDelegate() {} |